/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */

import type { AccountId } from "./AccountId";
import type { AccountJobId } from "./AccountJobId";
import type { AccountJobStatus } from "./AccountJobStatus";
import type { AccountJobType } from "./AccountJobType";
import type { EpochMillis } from "./EpochMillis";
import type { JobUrl } from "./JobUrl";
import type { JsonObject } from "./JsonObject";

/**
 * Summary information about an asynchronous background job (for example, a folder deletion).
 */
export type JobSummary = {
  /**
   * Link to the documentation that describes how to get a job's status from its job ID.
   */
  jobDocs: "https://upload.io/docs/upload-api/jobs/GetJob";
  /**
   * Unique ID for the job.
   */
  jobId: AccountJobId;
  /**
   * Type of the job.
   */
  jobType: AccountJobType;
  jobUrl: JobUrl;
  accountId: AccountId;
  /**
   * The time this job was created in epoch milliseconds (since midnight 1 January 1970, UTC).
   */
  created: EpochMillis;
  error: {
    /**
     * Human-readable error message.
     */
    message: string;
    /**
     * Additional machine-readable details relating to the error.
     */
    details?: any;
    /**
     * Machine-readable error code.
     */
    code: string;
  } | null;
  /**
   * The time this job was updated in epoch milliseconds (since midnight 1 January 1970, UTC).
   */
  lastUpdated: EpochMillis;
  /**
   * The job's status.
   */
  status: AccountJobStatus;
  /**
   * The `payload` and `jobType` together define the work the job will perform / has performed.
   */
  summary: JsonObject;
};
